package
Version:
v0.0.0-...-398e551
Opens a new window with list of versions in this module.
Published: May 21, 2022
License: MIT
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type AuthConfig struct {
Addr string `yaml:"addr"`
Port int `yaml:"port"`
SecretKey string `yaml:"key"`
}
type ConfigDB struct {
Username string `yaml:"username"`
Host string `yaml:"host"`
Port int `yaml:"port"`
Dbname string `yaml:"dbname"`
Password string `yaml:"password"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.